Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(843)

Unified Diff: content/browser/download/download_stats.h

Issue 66993008: [Downloads] Cleanup DownloadResourceHandler (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/download/download_stats.h
diff --git a/content/browser/download/download_stats.h b/content/browser/download/download_stats.h
index 9a9b1f28b4529e6253cc092f4c447ee4ef2e334e..293f0faad048789a6e97a3adedca63b879083e62 100644
--- a/content/browser/download/download_stats.h
+++ b/content/browser/download/download_stats.h
@@ -165,10 +165,12 @@ void RecordBandwidth(double actual_bandwidth, double potential_bandwidth);
void RecordOpen(const base::Time& end, bool first);
// Record whether or not the server accepts ranges, and the download size. Also
-// counts if a strong ETag is supplied. The combination of range request support
-// and ETag indicates downloads that are candidates for partial resumption.
-void RecordAcceptsRanges(const std::string& accepts_ranges, int64 download_len,
- const std::string& etag);
+// counts if a strong validator is supplied. The combination of range request
+// support and ETag indicates downloads that are candidates for partial
+// resumption.
+void RecordAcceptsRanges(const std::string& accepts_ranges,
+ int64 download_len,
+ bool has_strong_validator);
Randy Smith (Not in Mondays) 2013/11/18 22:07:02 This change makes me wary because we're changing w
asanka 2013/11/19 23:53:48 I deprecated the old UMA and added a new one.
// Record the number of downloads removed by ClearAll.
void RecordClearAllSize(int size);

Powered by Google App Engine
This is Rietveld 408576698